-- MIT LICENSE
-- Copyright (c) 2016 Steve Wolligandt
-- Permission is hereby granted, free of charge, to any person obtaining a
-- copy of this software and associated documentation files (the
-- "Software"), to deal in the Software without restriction, including
-- without limitation the rights to use, copy, modify, merge, publish,
-- distribute, sublicense, and/or sell copies of the Software, and to
-- permit persons to whom the Software is furnished to do so, subject to
-- the following conditions:
-- 
-- The above copyright notice and this permission notice shall be included
-- in all copies or substantial portions of the Software.
-- 
-- THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
-- OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-- MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-- IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
-- CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
-- TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-- SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

local NAN  =  0.0 / 0.0
local NINF = -math.huge
local PINF =  math.huge

--- Returns true if given value is a finite number; otherwise false or nil if value is not of type string nor number.
function math.finite(value)
  if type(value) == "string" then
    value = tonumber(value)
    if value == nil then return nil end
  elseif type(value) ~= "number" then
    return nil
  end
  return value > NINF and value < PINF
end

--- Returns 1 if given value is a positive infinity or -1 if given value is a negative infinity; otherwise 0 or nil if value is not of type string nor number.
function math.isinf(value)
  if type(value) == "string" then
    value = tonumber(value)
    if value == nil then return nil end
  elseif type(value) ~= "number" then
    return nil
  end
  if value == PINF then return 1 end
  if value == NINF then return -1 end
  return 0
end

--- Returns true if given value is not a number (NaN); otherwise false or nil if value is not of type string nor number.
function math.isnan(value)
  if type(value) == "string" then
    value = tonumber(value)
    if value == nil then return nil end
  elseif type(value) ~= "number" then
    return nil
  end
  return value ~= value
end