-- MIT LICENSE
-- Copyright (c) 2016 Steve Wolligandt
-- Permission is hereby granted, free of charge, to any person obtaining a
-- copy of this software and associated documentation files (the
-- "Software"), to deal in the Software without restriction, including
-- without limitation the rights to use, copy, modify, merge, publish,
-- distribute, sublicense, and/or sell copies of the Software, and to
-- permit persons to whom the Software is furnished to do so, subject to
-- the following conditions:
-- 
-- The above copyright notice and this permission notice shall be included
-- in all copies or substantial portions of the Software.
-- 
-- THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
-- OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-- MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-- IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
-- CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
-- TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-- SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

function drawGraphs() end
function printtext() end
function load() end


function love.load()
    scale = 70

    load()
    translation = {}
    translation.x = love.graphics.getWidth()/2
    translation.y = love.graphics.getHeight()/2
    
    oldMouse = {}
    oldMouse.x, oldMouse.y = love.mouse.getPosition()
end

function love.update(dt)
    local currentMouse = {}
    currentMouse.x, currentMouse.y = love.mouse.getPosition()

    local offset = {}
    offset.x = currentMouse.x - oldMouse.x
    offset.y = currentMouse.y - oldMouse.y
    oldMouse.x = currentMouse.x
    oldMouse.y = currentMouse.y

    if (love.mouse.isDown(1)) then
        translation.x = translation.x + offset.x
        translation.y = translation.y + offset.y
    end
end

function love.wheelmoved( dx, dy )
    local scrollFactor = 5
    local currentMouse = {}
    local coordinate =  {}
    local offset = {}

    currentMouse.x, currentMouse.y = love.mouse.getPosition()

    offset.x = (currentMouse.x - translation.x)/(scale/scrollFactor)
    offset.y = (currentMouse.y - translation.y)/(scale/scrollFactor)

    translation.x = translation.x - dy*offset.x
    translation.y = translation.y - dy*offset.y

    scale = scale + dy*scrollFactor
end

function drawCoordinateSystem()
    love.graphics.setColor(240,240,240)
    for i=-100,100,1 do love.graphics.line(-100,i,100,i) end
    for i=-100,100,1 do love.graphics.line(i,-100,i,100) end
    love.graphics.setColor(98,98,102)
    love.graphics.line(-100,0,100,0)
    love.graphics.line(0,-100,0,100)
end

function transform()
    love.graphics.origin()
    love.graphics.setLineWidth(1/love.graphics.getWidth())
    love.graphics.setPointSize(3)
    love.graphics.translate(translation.x, translation.y)
    love.graphics.scale(scale, scale)
end

function love.draw()
    transform()
    drawCoordinateSystem()
    drawGraphs()
    printtext()
end